[−][src]Module bbqueue::atomic
There are no longer separate 'atomic' and 'cm_mutex' modules. You can just use the types at the crate root.
There are no longer separate atomic and cm_mutex modules. You can just use the types at the
crate root.
Modules
| consts | Type aliases for many constants. |
Structs
| BBBuffer | A backing structure for a BBQueue. Can be used to create either a BBQueue or a split Producer/Consumer pair |
| ConstBBBuffer |
|
| Consumer |
|
| GrantR | A structure representing a contiguous region of memory that may be read from, and potentially "released" (or cleared) from the queue |
| GrantW | A structure representing a contiguous region of memory that may be written to, and potentially "committed" to the queue. |
| Producer |
|