CsCoord

Struct CsCoord 

pub struct CsCoord { /* private fields */ }
Coordination that uses a critical section to perform coordination operations

The critical section is only taken for a short time to obtain or release grants, not for the entire duration of the grant.

Implementations

Source

impl CsCoord

pub const fn new() -> Self

Create a new critical-section based coordination