[−][src]Module bbqueue::atomic
A version of BBQueue built on Atomic CAS capabilities. This is recommended if your platform supports it.
Modules
| consts | Type aliases for many constants. |
Structs
| BBBuffer | A backing structure for a BBQueue. Can be used to create either a BBQueue or a split Producer/Consumer pair |
| ConstBBBuffer |
|
| Consumer | |
| GrantR | A structure representing a contiguous region of memory that may be read from, and potentially "released" (or cleared) from the queue |
| GrantW | A structure representing a contiguous region of memory that may be written to, and potentially "committed" to the queue |
| Producer |